==> patternfly__react-tokens-5.1.0.jar: META-INF/resources/webjars/patternfly__react-tokens/5.1.0/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# 5.1.0 (2023-07-27)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.1.0-prerelease.0 (2023-07-27)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0 (2023-07-27)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.9 (2023-07-20)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.0.0-prerelease.8](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.0.0-prerelease.7...@patternfly/react-tokens@5.0.0-prerelease.8) (2023-07-14)

### Reverts

- Revert "Add transformation fallback (#9353)" (#9365) ([b2cd563](https://github.com/patternfly/patternfly-react/commit/b2cd563207194c2312d5760d91e425182fba2cd1)), closes [#9353](https://github.com/patternfly/patternfly-react/issues/9353) [#9365](https://github.com/patternfly/patternfly-react/issues/9365)

# 5.0.0-prerelease.7 (2023-07-13)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.6 (2023-07-06)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.5 (2023-06-21)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.4 (2023-06-15)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.3 (2023-06-13)

### Bug Fixes

- **docs:** update use of deprecated tag and clean up changelogs ([#9259](https://github.com/patternfly/patternfly-react/issues/9259)) ([8de83dc](https://github.com/patternfly/patternfly-react/commit/8de83dc3b2fb88094fd3c21bda2ed6e371986cba))

# [5.0.0-prerelease.2](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.0.0-prerelease.1...@patternfly/react-tokens@5.0.0-prerelease.2) (2023-06-06)

### Bug Fixes

- **versions:** bump core and fix demo-app versions ([#9248](https://github.com/patternfly/patternfly-react/issues/9248)) ([d19f9d2](https://github.com/patternfly/patternfly-react/commit/d19f9d21c39574784074ee1def886a6da21b2274))

# 5.0.0-prerelease.1 (2023-06-06)

### Bug Fixes

- **release:** dryrun publishing prereleases ([#9242](https://github.com/patternfly/patternfly-react/issues/9242)) ([e4c35f1](https://github.com/patternfly/patternfly-react/commit/e4c35f14cd57be132179e51ae2bb223600a35f0e))

# 5.0.0-alpha.16 (2023-06-02)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.15 (2023-05-31)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.14 (2023-05-19)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.13 (2023-05-18)

### Features

- **Flex:** add plain gap spacing ([#9143](https://github.com/patternfly/patternfly-react/issues/9143)) ([eceb265](https://github.com/patternfly/patternfly-react/commit/eceb265a5318d4c533a4c54484311bbd9810aa7d))

# 5.0.0-alpha.12 (2023-05-18)

### Features

- **Table:** added class names for table elements ([#9133](https://github.com/patternfly/patternfly-react/issues/9133)) ([51d6d2b](https://github.com/patternfly/patternfly-react/commit/51d6d2b1a92af7bbfb0075361b375a4d881e110b))

# 5.0.0-alpha.11 (2023-05-18)

### Features

- **FormControls:** updated logic for rendering icons ([#9132](https://github.com/patternfly/patternfly-react/issues/9132)) ([9f4863f](https://github.com/patternfly/patternfly-react/commit/9f4863f3251e365142c44aace2c1aeba57ba6b3a))

# 5.0.0-alpha.10 (2023-05-16)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.0.0-alpha.9](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.0.0-alpha.8...@patternfly/react-tokens@5.0.0-alpha.9) (2023-05-05)

### Bug Fixes

- **deps:** updated Core for v5 versioning ([#9075](https://github.com/patternfly/patternfly-react/issues/9075)) ([3879fc7](https://github.com/patternfly/patternfly-react/commit/3879fc757aefeed80b0694365aa20d5ca856a797))

# 5.0.0-alpha.8 (2023-05-05)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.7 (2023-04-25)

### Bug Fixes

- bump dependencies and remove ssl option ([#8984](https://github.com/patternfly/patternfly-react/issues/8984)) ([f8f77d2](https://github.com/patternfly/patternfly-react/commit/f8f77d232b386ad8676af609273d9adff5a5feae))

# 5.0.0-alpha.6 (2023-04-03)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.5 (2023-03-18)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.4 (2023-03-02)

### Bug Fixes

- **core:** update core to alpha.24 ([#8768](https://github.com/patternfly/patternfly-react/issues/8768)) ([6dd5e01](https://github.com/patternfly/patternfly-react/commit/6dd5e01e16bc94fe4b954b79ba67adaaab9c7135))

# 5.0.0-alpha.3 (2023-02-15)

### Bug Fixes

- **deps:** updated to the latest core alpha ([#8688](https://github.com/patternfly/patternfly-react/issues/8688)) ([5f81928](https://github.com/patternfly/patternfly-react/commit/5f819288d7baaa3806b23c0da8fb26dd4ec12d6b))

# 5.0.0-alpha.2 (2023-02-08)

**Note:** Version bump only for package @patternfly/react-tokens

==> patternfly__react-tokens-5.4.1.jar: META-INF/resources/webjars/patternfly__react-tokens/5.4.1/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [5.4.1](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.4.0...@patternfly/react-tokens@5.4.1) (2024-10-17)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.4.0 (2024-08-27)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.4.0-prerelease.10](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.4.0-prerelease.9...@patternfly/react-tokens@5.4.0-prerelease.10) (2024-07-16)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.4.0-prerelease.9](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.4.0-prerelease.8...@patternfly/react-tokens@5.4.0-prerelease.9) (2024-07-11)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.4.0-prerelease.8](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.4.0-prerelease.7...@patternfly/react-tokens@5.4.0-prerelease.8) (2024-07-02)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.4.0-prerelease.7](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.4.0-prerelease.6...@patternfly/react-tokens@5.4.0-prerelease.7) (2024-07-01)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.4.0-prerelease.6](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.4.0-prerelease.5...@patternfly/react-tokens@5.4.0-prerelease.6) (2024-06-13)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.4.0-prerelease.5](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.4.0-prerelease.4...@patternfly/react-tokens@5.4.0-prerelease.5) (2024-05-31)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.4.0-prerelease.4](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.4.0-prerelease.3...@patternfly/react-tokens@5.4.0-prerelease.4) (2024-05-20)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.4.0-prerelease.3](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.4.0-prerelease.2...@patternfly/react-tokens@5.4.0-prerelease.3) (2024-05-10)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.4.0-prerelease.2 (2024-04-30)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.4.0-prerelease.1 (2024-04-19)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.4.0-prerelease.0 (2024-04-18)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.3.0 (2024-04-18)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.3.0-prerelease.3 (2024-03-26)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.3.0-prerelease.2 (2024-03-22)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.3.0-prerelease.1 (2024-02-28)

### Bug Fixes

- **deps:** bump to latest core ([#10116](https://github.com/patternfly/patternfly-react/issues/10116)) ([dc1aceb](https://github.com/patternfly/patternfly-react/commit/dc1aceb0ee880631320b85bfb068be13d7852a37))

# 5.3.0-prerelease.0 (2024-02-02)

# 5.2.0 (2024-02-02)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.2.0 (2024-02-02)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.2.0-prerelease.7 (2023-12-11)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.2.0-prerelease.6 (2023-11-10)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.2.0-prerelease.5 (2023-11-03)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.2.0-prerelease.4 (2023-10-26)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.2.0-prerelease.3 (2023-10-10)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.2.0-prerelease.2](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.2.0-prerelease.1...@patternfly/react-tokens@5.2.0-prerelease.2) (2023-10-10)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.2.0-prerelease.1 (2023-10-09)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.2.0-prerelease.0](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.1.1...@patternfly/react-tokens@5.2.0-prerelease.0) (2023-10-05)

**Note:** Version bump only for package @patternfly/react-tokens

## [5.1.1](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.1.1-prerelease.8...@patternfly/react-tokens@5.1.1) (2023-10-05)

**Note:** Version bump only for package @patternfly/react-tokens

## 5.1.1-prerelease.8 (2023-10-03)

### Bug Fixes

- whitespace changes to trigger prereleases ([#9702](https://github.com/patternfly/patternfly-react/issues/9702)) ([741c248](https://github.com/patternfly/patternfly-react/commit/741c24825b503e116c77cf304aa3e4e3a9ff7841))

## 5.1.1-prerelease.7 (2023-09-21)

**Note:** Version bump only for package @patternfly/react-tokens

## 5.1.1-prerelease.6 (2023-09-18)

**Note:** Version bump only for package @patternfly/react-tokens

## [5.1.1-prerelease.5](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.1.1-prerelease.4...@patternfly/react-tokens@5.1.1-prerelease.5) (2023-09-07)

**Note:** Version bump only for package @patternfly/react-tokens

## [5.1.1-prerelease.4](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.1.1-prerelease.3...@patternfly/react-tokens@5.1.1-prerelease.4) (2023-09-06)

**Note:** Version bump only for package @patternfly/react-tokens

## 5.1.1-prerelease.3 (2023-09-05)

**Note:** Version bump only for package @patternfly/react-tokens

## 5.1.1-prerelease.2 (2023-08-31)

**Note:** Version bump only for package @patternfly/react-tokens

## 5.1.1-prerelease.1 (2023-08-29)

# 5.0.0 (2023-07-27)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.1.0-prerelease.0](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.0.0...@patternfly/react-tokens@5.1.0-prerelease.0) (2023-07-27)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0 (2023-07-27)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.9 (2023-07-20)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.0.0-prerelease.8](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.0.0-prerelease.7...@patternfly/react-tokens@5.0.0-prerelease.8) (2023-07-14)

### Reverts

- Revert "Add transformation fallback (#9353)" (#9365) ([b2cd563](https://github.com/patternfly/patternfly-react/commit/b2cd563207194c2312d5760d91e425182fba2cd1)), closes [#9353](https://github.com/patternfly/patternfly-react/issues/9353) [#9365](https://github.com/patternfly/patternfly-react/issues/9365)

# 5.0.0-prerelease.7 (2023-07-13)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.6 (2023-07-06)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.5 (2023-06-21)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.4 (2023-06-15)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-prerelease.3 (2023-06-13)

### Bug Fixes

- **docs:** update use of deprecated tag and clean up changelogs ([#9259](https://github.com/patternfly/patternfly-react/issues/9259)) ([8de83dc](https://github.com/patternfly/patternfly-react/commit/8de83dc3b2fb88094fd3c21bda2ed6e371986cba))

# [5.0.0-prerelease.2](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.0.0-prerelease.1...@patternfly/react-tokens@5.0.0-prerelease.2) (2023-06-06)

### Bug Fixes

- **versions:** bump core and fix demo-app versions ([#9248](https://github.com/patternfly/patternfly-react/issues/9248)) ([d19f9d2](https://github.com/patternfly/patternfly-react/commit/d19f9d21c39574784074ee1def886a6da21b2274))

# 5.0.0-prerelease.1 (2023-06-06)

### Bug Fixes

- **release:** dryrun publishing prereleases ([#9242](https://github.com/patternfly/patternfly-react/issues/9242)) ([e4c35f1](https://github.com/patternfly/patternfly-react/commit/e4c35f14cd57be132179e51ae2bb223600a35f0e))

# 5.0.0-alpha.16 (2023-06-02)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.15 (2023-05-31)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.14 (2023-05-19)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.13 (2023-05-18)

### Features

- **Flex:** add plain gap spacing ([#9143](https://github.com/patternfly/patternfly-react/issues/9143)) ([eceb265](https://github.com/patternfly/patternfly-react/commit/eceb265a5318d4c533a4c54484311bbd9810aa7d))

# 5.0.0-alpha.12 (2023-05-18)

### Features

- **Table:** added class names for table elements ([#9133](https://github.com/patternfly/patternfly-react/issues/9133)) ([51d6d2b](https://github.com/patternfly/patternfly-react/commit/51d6d2b1a92af7bbfb0075361b375a4d881e110b))

# 5.0.0-alpha.11 (2023-05-18)

### Features

- **FormControls:** updated logic for rendering icons ([#9132](https://github.com/patternfly/patternfly-react/issues/9132)) ([9f4863f](https://github.com/patternfly/patternfly-react/commit/9f4863f3251e365142c44aace2c1aeba57ba6b3a))

# 5.0.0-alpha.10 (2023-05-16)

**Note:** Version bump only for package @patternfly/react-tokens

# [5.0.0-alpha.9](https://github.com/patternfly/patternfly-react/compare/@patternfly/react-tokens@5.0.0-alpha.8...@patternfly/react-tokens@5.0.0-alpha.9) (2023-05-05)

### Bug Fixes

- **deps:** updated Core for v5 versioning ([#9075](https://github.com/patternfly/patternfly-react/issues/9075)) ([3879fc7](https://github.com/patternfly/patternfly-react/commit/3879fc757aefeed80b0694365aa20d5ca856a797))

# 5.0.0-alpha.8 (2023-05-05)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.7 (2023-04-25)

### Bug Fixes

- bump dependencies and remove ssl option ([#8984](https://github.com/patternfly/patternfly-react/issues/8984)) ([f8f77d2](https://github.com/patternfly/patternfly-react/commit/f8f77d232b386ad8676af609273d9adff5a5feae))

# 5.0.0-alpha.6 (2023-04-03)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.5 (2023-03-18)

**Note:** Version bump only for package @patternfly/react-tokens

# 5.0.0-alpha.4 (2023-03-02)

### Bug Fixes

- **core:** update core to alpha.24 ([#8768](https://github.com/patternfly/patternfly-react/issues/8768)) ([6dd5e01](https://github.com/patternfly/patternfly-react/commit/6dd5e01e16bc94fe4b954b79ba67adaaab9c7135))

# 5.0.0-alpha.3 (2023-02-15)

### Bug Fixes

- **deps:** updated to the latest core alpha ([#8688](https://github.com/patternfly/patternfly-react/issues/8688)) ([5f81928](https://github.com/patternfly/patternfly-react/commit/5f819288d7baaa3806b23c0da8fb26dd4ec12d6b))

# 5.0.0-alpha.2 (2023-02-08)

**Note:** Version bump only for package @patternfly/react-tokens
